<?php
// +-----------------------------------------------------------------------+
// | photoWidget  - a plugin for Piwigo                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2010-2013 Nicolas Roudaire        http://www.nikrou.net  |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License version 2 as     |
// | published by the Free Software Foundation                             |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            |
// | MA 02110-1301 USA                                                     |
// +-----------------------------------------------------------------------+

class photoWidgetContent
{
  private $show_xml_list = false, $applicable = false;
  
  public function __construct($config) {
    $this->plugin_config = $config;
  }

  public function loc_begin_index() {
    global $page;

    $this->applicable = false;
    
    if (!empty($page['category'])) {
      if ($this->plugin_config->pw_all_categories==1 or
          (is_array($this->plugin_config->pw_categories) &&
           in_array($page['category']['id'], $this->plugin_config->pw_categories)))
      {
        $this->applicable = true;
      }
    }

    $match_content = $_SERVER['QUERY_STRING'];
    if (PHPWG_ROOT_PATH != $page['root_path'] && !empty($_SERVER['PATH_INFO'])) {
      $match_content = $_SERVER['PATH_INFO'];
    }

    $xml_pattern = '#/pw\.xml$#';
    if (preg_match($xml_pattern, $match_content)) {
      $this->show_xml_list = true;
    }
  }

  public function loc_begin_index_thumbnails($images) {
    global $template, $page;
    
    if (!$this->applicable) {
      return;
    }

    if ($this->show_xml_list)
    {
      foreach ($images as &$image) {
        $image['url'] = duplicate_picture_url(
          array('image_id' => $image['id'],
                'image_file' => $image['file']
            ),
          array('start')
          );
      }
      $this->pw_xml($images);
    }

    $template->set_filename('index_thumbnails', PW_TEMPLATE . '/animation.tpl');
    $template->assign('PW_XML', $this->getXmlPath($page['category']));
    $template->assign('PW_BGCOLOR', $this->plugin_config->pw_bgcolor);
    $template->assign('PW_WIDTH', $this->plugin_config->pw_width);
    $template->assign('PW_HEIGHT', $this->plugin_config->pw_height);
    $template->assign('PW_SWF_ANIMATION', PW_SWF . '/photowidget.swf');
  }

  public function loc_begin_index_category_thumbnails($categories) {
    global $template, $page;
    
    if (!$this->applicable) {
      return;
    }

    if ($this->show_xml_list)
    {
      $image_ids = array();
      foreach ($categories as $category) {
        $image_ids[] = $category['representative_picture_id'];
      }
      $thumbnail_src_of = array();
      
      $query = '
SELECT id, path, tn_ext
  FROM '.IMAGES_TABLE.'
  WHERE id IN ('.implode(',', $image_ids).')
;';
      $result = pwg_query($query);
      while ($row = pwg_db_fetch_assoc($result)) {
        $thumbnail_src_of[$row['id']] = get_thumbnail_url($row);
      }

      foreach ($categories as &$category) {
        $category['url'] = make_index_url(array('category' => $category));
        $category['path'] = $thumbnail_src_of[$category['representative_picture_id']];
      }
      $this->pw_xml($categories);
    }
    
    $template->set_filename('index_category_thumbnails', PW_TEMPLATE . '/animation.tpl');
    $template->assign('PW_XML', $this->getXmlPath($page['category']));
    $template->assign('PW_BGCOLOR', $this->plugin_config->pw_bgcolor);
    $template->assign('PW_WIDTH', $this->plugin_config->pw_width);
    $template->assign('PW_HEIGHT', $this->plugin_config->pw_height);
    $template->assign('PW_SWF_ANIMATION', PW_SWF . '/photowidget.swf');
  }

  private function getXmlPath($category) {
    global $page;

    return sprintf(
      '%s/pw.xml',
      make_index_url(
        array(
          'section' => 'categories',
          'category' => $page['category']
          )
        )
      );
  }

  private function pw_xml($images) {
    include PW_TEMPLATE . '/liste.xml';
    exit();
  }
}
